.. Enaml documentation master file

Welcome to Enaml's documentation!
====================================

**E**\naml is **N**\ot **A** **M**\arkup **L**\anguage. |Enaml| is a tool for
building *durable visual layers that hold up well under heavy use*. It is a
declarative language based on Python, analogous to Qt's QML, that makes
development of GUI's for Python both easy and effective. |Enaml| currently
supports wxWidgets as a backend via wxPython, and Qt as a backend via PySide
and PyQt4. However, it is not tied to a single widget toolkit.

.. warning:: |Enaml| is currently under heavy development and the
    documentation is not always up-to-date. Please recompile in order to
    have the latest changes from the source code.


.. toctree::
    :maxdepth: 2

    Getting Started Guide & Tutorials <instructional/index.rst>
    Technical Reference <tech_ref/index.rst>
    Architecture Reference <architecture/index.rst>
    Developer's Guide <developer_guide/index.rst>




